@@ -1,7 +1,7 @@
-# 
+#
 # namcap rules - __init__
 # Copyright (C) 2003-2009 Jason Chu <jason@archlinux.org>
-# 
+#
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
 #   the Free Software Foundation; either version 2 of the License, or
@@ -15,7 +15,7 @@
 #   You should have received a copy of the GNU General Public License
 #   along with this program; if not, write to the Free Software
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-# 
+#
 
 from types import ModuleType
 import Namcap.ruleclass
@@ -31,13 +31,13 @@ from . import (
   fileownership,
   gnomemime,
   hardlinks,
+  hookdepends,
   infodirectory,
   javafiles,
   kdeprograms,
   libtool,
   licensepkg,
   lotsofdocs,
-  mimefiles,
   missingbackups,
   pathdepends,
   perllocal,
@@ -59,6 +59,7 @@ from . import (
   carch,
   extravars,
   invalidstartdir,
+  makedepends,
   makepkgfunctions,
   missingvars,
   pkginfo,
