@@ -1,7 +1,7 @@
-# 
+#
 # namcap rules - extravars
 # Copyright (C) 2003-2009 Jesse Young <jesseyoung@gmail.com>
-# 
+#
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
 #   the Free Software Foundation; either version 2 of the License, or
@@ -15,7 +15,7 @@
 #   You should have received a copy of the GNU General Public License
 #   along with this program; if not, write to the Free Software
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-# 
+#
 
 from itertools import product
 from Namcap.ruleclass import *
@@ -26,12 +26,13 @@ class package(PkgbuildRule):
 	def analyze(self, pkginfo, tar):
 		carch_vars = ['checkdepends', 'conflicts', 'depends', 'makedepends',
 				 'optdepends', 'provides', 'replaces', 'source', 'md5sums',
-				 'sha224sums', 'sha1sums', 'sha256sums', 'sha384sums', 'sha512sums']
+				 'sha224sums', 'sha1sums', 'sha256sums', 'sha384sums',
+				 'sha512sums', 'b2sums']
 		stdvars = ['arch', 'license', 'backup', 'noextract', 'pkgname',
 				 'pkgbase', 'pkgver', 'pkgrel', 'epoch', 'pkgdesc', 'groups',
 				 'url', 'install', 'changelog',
 				 'options', 'validpgpkeys'] + carch_vars
-		if 'arch' in pkginfo and len(pkginfo["arch"]) >= 2:
+		if 'arch' in pkginfo and pkginfo['arch'] != ['any']:
 			stdvars.extend(v+'_'+a for v,a in product(carch_vars, pkginfo["arch"]))
 		for varname in pkginfo["setvars"]:
 			if varname.islower() and varname not in stdvars \
